@@ -1,13 +1,13 @@
 package HTML::FormFu::Deflator;
 
 use strict;
-use base 'Class::Accessor::Chained::Fast';
 use Class::C3;
 
-use HTML::FormFu::ObjectUtil qw( populate form name );
+use HTML::FormFu::Attribute qw( mk_accessors );
+use HTML::FormFu::ObjectUtil qw( populate form name parent );
 use Carp qw( croak );
 
-__PACKAGE__->mk_accessors(qw/ parent type /);
+__PACKAGE__->mk_accessors(qw/ type /);
 
 sub new {
     my $class = shift;
@@ -48,7 +48,7 @@ __END__
 
 =head1 NAME
 
-HTML::FormFu::Filter - Deflator Base Class
+HTML::FormFu::Deflator - Deflator Base Class
 
 =head1 SYNOPSIS
 
